==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/grph1/szpack/sztxwv.c <==
/* src/grph1/szpack/sztxwv.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Common Block Declarations */

struct {
    real qsize, ct, st;
    integer icentz;
} szbtx1_;

#define szbtx1_1 szbtx1_

struct {
    logical lcntl;
    integer jsup, jsub, jrst;
    real small, shift;
} szbtx2_;

#define szbtx2_1 szbtx2_

/* Table of constant values */

static integer c__1 = 1;
static integer c__3 = 3;

/* ----------------------------------------------------------------------- */
/*     BASIC TEXT PRIMITIVE ON VC */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int sztxwv_(real *vx, real *vy, char *chars, ftnlen 
	chars_len)
{
    /* Initialized data */

    static integer ncntz = 0;

    /* System generated locals */
    address a__1[3];
    integer i__1, i__2, i__3[3];
    char ch__1[83];
    icilist ici__1;

    /* Builtin functions */
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;
    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);

    /* Local variables */
    static integer k, n, nc, ip;
    static real xc, yc;
    static integer np, nx, ny;
    static real xp, yp, wx, wy, vx1, wx1[256], wx2[256], vx2;
    static integer idx;
    static char ckx[1*6000], cky[1*6000];
    static integer icz, ncz, ips;
    static real fnx, fny;
    static char cobj[80], cbuf[80];
    extern integer lenc_(char *, ftnlen);
    static integer mode;
    extern integer isgc_(char *, ftnlen);
    static integer ncnt;
    static real offx, offy, wxch, wych;
    static integer mode0;
    extern /* Subroutine */ int cdblk_(char *, ftnlen);
    static real factz;
    static integer iposx[256];
    extern /* Subroutine */ int swocls_(char *, ftnlen), szfint_(integer *), 
	    szclsv_(void), szqfnt_(integer *, char *, char *, ftnlen, ftnlen),
	     swoopn_(char *, char *, ftnlen, ftnlen), szqfnw_(real *, real *),
	     stfwtr_(real *, real *, real *, real *), szplsv_(real *, real *),
	     szopsv_(void), szmvsv_(real *, real *), szqtxw_(char *, integer *
	    , real *, real *, ftnlen);

    /* Fortran I/O blocks */
    static icilist io___19 = { 0, cobj, 0, "(2I8)", 80, 1 };


/*     / GET FONT INFORMATION / */
    szfint_(&ncnt);
    if (ncntz != ncnt) {
	szqfnt_(iposx, ckx, cky, (ftnlen)1, (ftnlen)1);
	szqfnw_(wx1, wx2);
	ncntz = ncnt;
    }
/*     / CHECK CHARACTER WIDTH AND HEIGHT / */
    ncz = lenc_(chars, chars_len);
    szqtxw_(chars, &nc, &wxch, &wych, chars_len);
/*     / WRITE INFORMATION FOR PS DRIVER / */
    stfwtr_(vx, vy, &wx, &wy);
    s_copy(cbuf, " ", (ftnlen)80, (ftnlen)1);
    np = 0;
    i__1 = ncz;
    for (n = 1; n <= i__1; ++n) {
	icz = isgc_(chars + (n - 1), (ftnlen)1);
	++np;
	if (32 <= icz && icz <= 127 && icz != 37) {
	    *(unsigned char *)&cbuf[np - 1] = *(unsigned char *)&chars[n - 1];
	} else {
	    ici__1.icierr = 0;
	    ici__1.icirnum = 1;
	    ici__1.icirlen = 4;
	    ici__1.iciunit = cbuf + (np - 1);
	    ici__1.icifmt = "(A,I3.3)";
	    s_wsfi(&ici__1);
	    do_fio(&c__1, "%", (ftnlen)1);
	    do_fio(&c__1, (char *)&icz, (ftnlen)sizeof(integer));
	    e_wsfi();
	    np += 3;
	}
/* L5: */
    }
    s_wsfi(&io___19);
    i__1 = (integer) wx;
    do_fio(&c__1, (char *)&i__1, (ftnlen)sizeof(integer));
    i__2 = (integer) wy;
    do_fio(&c__1, (char *)&i__2, (ftnlen)sizeof(integer));
    e_wsfi();
    cdblk_(cobj, (ftnlen)80);
    i__1 = lenc_(cobj, (ftnlen)80);
    ici__1.icierr = 0;
    ici__1.icirnum = 1;
    ici__1.icirlen = 80 - i__1;
    ici__1.iciunit = cobj + i__1;
    ici__1.icifmt = "(A)";
    s_wsfi(&ici__1);
/* Writing concatenation */
    i__3[0] = 2, a__1[0] = " \"";
    i__3[1] = np, a__1[1] = cbuf;
    i__3[2] = 1, a__1[2] = "\"";
    s_cat(ch__1, a__1, i__3, &c__3, (ftnlen)83);
    do_fio(&c__1, ch__1, np + 3);
    e_wsfi();
    swoopn_("SZTXZ", cobj, (ftnlen)5, (ftnlen)80);
/*     / CALCULATE OFFSET VALUES / */
    offx = wxch * -.5f * 24.f * (szbtx1_1.icentz + 1);
    offy = 0.f;
    xc = *vx + offx * szbtx1_1.ct - offy * szbtx1_1.st;
    yc = *vy + offx * szbtx1_1.st + offy * szbtx1_1.ct;
/*     / INITIALIZATION / */
    mode0 = 0;
    mode = 0;
    factz = 1.f;
    vx1 = 0.f;
/*     / PROCESS EACH CHARACTER / */
    i__1 = ncz;
    for (k = 1; k <= i__1; ++k) {
/*       / CHARACTER CONVERSION / */
	idx = isgc_(chars + (k - 1), (ftnlen)1) + 1;
	ips = iposx[idx - 1] + 1;
/*       / CHECK CONTROL CHARACTERS / */
	if (szbtx2_1.lcntl && (idx == szbtx2_1.jsub || idx == szbtx2_1.jsup ||
		 idx == szbtx2_1.jrst)) {
	    if (idx == szbtx2_1.jsub) {
		mode = -1;
		factz = szbtx2_1.small;
	    } else if (idx == szbtx2_1.jsup) {
		mode = 1;
		factz = szbtx2_1.small;
	    } else if (idx == szbtx2_1.jrst) {
		mode = 0;
		factz = 1.f;
	    }
	    goto L20;
	}
	vx2 = -wx1[idx - 1];
	if (mode0 == mode) {
	    if (mode == 0) {
		fnx = vx1 + vx2;
	    } else {
		fnx = (vx1 + vx2) * szbtx2_1.small;
	    }
	    fny = 0.f;
	} else {
	    if (mode0 * mode == 0) {
		if (mode == 0) {
		    fnx = vx1 * szbtx2_1.small + vx2;
		} else {
		    fnx = vx2 + vx1 * szbtx2_1.small;
		}
	    } else {
/*           'IS THIS BLOCK REALLY NECESSARY?' */
		fnx = (vx1 + vx2) * szbtx2_1.small;
	    }
	    fny = szbtx2_1.shift * 24.f * (mode - mode0);
	}
	mode0 = mode;
	xc = xc + fnx * szbtx1_1.ct - fny * szbtx1_1.st;
	yc = yc + fnx * szbtx1_1.st + fny * szbtx1_1.ct;
	vx1 = wx2[idx - 1];
	szopsv_();
	ip = 0;
L10:
	nx = *(unsigned char *)&ckx[ips - 1] - 64;
	fnx = nx * factz;
	ny = *(unsigned char *)&cky[ips - 1] - 64;
	fny = -ny * factz;
	if (nx != -64) {
	    xp = xc + fnx * szbtx1_1.ct - fny * szbtx1_1.st;
	    yp = yc + fnx * szbtx1_1.st + fny * szbtx1_1.ct;
	    if (ip == 0) {
		szmvsv_(&xp, &yp);
	    } else if (ip == 1) {
		szplsv_(&xp, &yp);
	    }
	    ip = 1;
	} else {
	    ip = 0;
	}
	++ips;
	if (! (nx == -64 && ny == -64)) {
	    goto L10;
	}
	szclsv_();
L20:
	;
    }
    swocls_("SZTXZ", (ftnlen)5);
    return 0;
} /* sztxwv_ */

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph1/szpack/sztxwv.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Common Block Declarations */

struct {
    real qsize, ct, st;
    integer icentz;
} szbtx1_;

#define szbtx1_1 szbtx1_

struct {
    logical lcntl;
    integer jsup, jsub, jrst;
    real small, shift;
} szbtx2_;

#define szbtx2_1 szbtx2_

/* Table of constant values */

static integer c__1 = 1;
static integer c__3 = 3;

/* ----------------------------------------------------------------------- */
/*     BASIC TEXT PRIMITIVE ON VC */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int sztxwv_(real *vx, real *vy, char *chars, ftnlen 
	chars_len)
{
    /* Initialized data */

    static integer ncntz = 0;

    /* System generated locals */
    address a__1[3];
    integer i__1, i__2, i__3[3];
    char ch__1[83];
    icilist ici__1;

    /* Builtin functions */
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;
    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);

    /* Local variables */
    static integer k, n, nc, ip;
    static real xc, yc;
    static integer np, nx, ny;
    static real xp, yp, wx, wy, vx1, wx1[256], wx2[256], vx2;
    static integer idx;
    static char ckx[1*6000], cky[1*6000];
    static integer icz, ncz, ips;
    static real fnx, fny;
    static char cobj[80], cbuf[80];
    extern integer lenc_(char *, ftnlen);
    static integer mode;
    extern integer isgc_(char *, ftnlen);
    static integer ncnt;
    static real offx, offy, wxch, wych;
    static integer mode0;
    extern /* Subroutine */ int cdblk_(char *, ftnlen);
    static real factz;
    static integer iposx[256];
    extern /* Subroutine */ int swocls_(char *, ftnlen), szfint_(integer *), 
	    szclsv_(void), szqfnt_(integer *, char *, char *, ftnlen, ftnlen),
	     swoopn_(char *, char *, ftnlen, ftnlen), szqfnw_(real *, real *),
	     stfwtr_(real *, real *, real *, real *), szplsv_(real *, real *),
	     szopsv_(void), szmvsv_(real *, real *), szqtxw_(char *, integer *
	    , real *, real *, ftnlen);

    /* Fortran I/O blocks */
    static icilist io___19 = { 0, cobj, 0, "(2I8)", 80, 1 };


/*     / GET FONT INFORMATION / */
    szfint_(&ncnt);
    if (ncntz != ncnt) {
	szqfnt_(iposx, ckx, cky, (ftnlen)1, (ftnlen)1);
	szqfnw_(wx1, wx2);
	ncntz = ncnt;
    }
/*     / CHECK CHARACTER WIDTH AND HEIGHT / */
    ncz = lenc_(chars, chars_len);
    szqtxw_(chars, &nc, &wxch, &wych, chars_len);
/*     / WRITE INFORMATION FOR PS DRIVER / */
    stfwtr_(vx, vy, &wx, &wy);
    s_copy(cbuf, " ", (ftnlen)80, (ftnlen)1);
    np = 0;
    i__1 = ncz;
    for (n = 1; n <= i__1; ++n) {
	icz = isgc_(chars + (n - 1), (ftnlen)1);
	++np;
	if (32 <= icz && icz <= 127 && icz != 37) {
	    *(unsigned char *)&cbuf[np - 1] = *(unsigned char *)&chars[n - 1];
	} else {
	    ici__1.icierr = 0;
	    ici__1.icirnum = 1;
	    ici__1.icirlen = 4;
	    ici__1.iciunit = cbuf + (np - 1);
	    ici__1.icifmt = "(A,I3.3)";
	    s_wsfi(&ici__1);
	    do_fio(&c__1, "%", (ftnlen)1);
	    do_fio(&c__1, (char *)&icz, (ftnlen)sizeof(integer));
	    e_wsfi();
	    np += 3;
	}
/* L5: */
    }
    s_wsfi(&io___19);
    i__1 = (integer) wx;
    do_fio(&c__1, (char *)&i__1, (ftnlen)sizeof(integer));
    i__2 = (integer) wy;
    do_fio(&c__1, (char *)&i__2, (ftnlen)sizeof(integer));
    e_wsfi();
    cdblk_(cobj, (ftnlen)80);
    i__1 = lenc_(cobj, (ftnlen)80);
    ici__1.icierr = 0;
    ici__1.icirnum = 1;
    ici__1.icirlen = 80 - i__1;
    ici__1.iciunit = cobj + i__1;
    ici__1.icifmt = "(A)";
    s_wsfi(&ici__1);
/* Writing concatenation */
    i__3[0] = 2, a__1[0] = " \"";
    i__3[1] = np, a__1[1] = cbuf;
    i__3[2] = 1, a__1[2] = "\"";
    s_cat(ch__1, a__1, i__3, &c__3, (ftnlen)83);
    do_fio(&c__1, ch__1, np + 3);
    e_wsfi();
    swoopn_("SZTXZ", cobj, (ftnlen)5, (ftnlen)80);
/*     / CALCULATE OFFSET VALUES / */
    offx = wxch * -.5f * 24.f * (szbtx1_1.icentz + 1);
    offy = 0.f;
    xc = *vx + offx * szbtx1_1.ct - offy * szbtx1_1.st;
    yc = *vy + offx * szbtx1_1.st + offy * szbtx1_1.ct;
/*     / INITIALIZATION / */
    mode0 = 0;
    mode = 0;
    factz = 1.f;
    vx1 = 0.f;
/*     / PROCESS EACH CHARACTER / */
    i__1 = ncz;
    for (k = 1; k <= i__1; ++k) {
/*       / CHARACTER CONVERSION / */
	idx = isgc_(chars + (k - 1), (ftnlen)1) + 1;
	ips = iposx[idx - 1] + 1;
/*       / CHECK CONTROL CHARACTERS / */
	if (szbtx2_1.lcntl && (idx == szbtx2_1.jsub || idx == szbtx2_1.jsup ||
		 idx == szbtx2_1.jrst)) {
	    if (idx == szbtx2_1.jsub) {
		mode = -1;
		factz = szbtx2_1.small;
	    } else if (idx == szbtx2_1.jsup) {
		mode = 1;
		factz = szbtx2_1.small;
	    } else if (idx == szbtx2_1.jrst) {
		mode = 0;
		factz = 1.f;
	    }
	    goto L20;
	}
	vx2 = -wx1[idx - 1];
	if (mode0 == mode) {
	    if (mode == 0) {
		fnx = vx1 + vx2;
	    } else {
		fnx = (vx1 + vx2) * szbtx2_1.small;
	    }
	    fny = 0.f;
	} else {
	    if (mode0 * mode == 0) {
		if (mode == 0) {
		    fnx = vx1 * szbtx2_1.small + vx2;
		} else {
		    fnx = vx2 + vx1 * szbtx2_1.small;
		}
	    } else {
/*           'IS THIS BLOCK REALLY NECESSARY?' */
		fnx = (vx1 + vx2) * szbtx2_1.small;
	    }
	    fny = szbtx2_1.shift * 24.f * (mode - mode0);
	}
	mode0 = mode;
	xc = xc + fnx * szbtx1_1.ct - fny * szbtx1_1.st;
	yc = yc + fnx * szbtx1_1.st + fny * szbtx1_1.ct;
	vx1 = wx2[idx - 1];
	szopsv_();
	ip = 0;
L10:
	nx = *(unsigned char *)&ckx[ips - 1] - 64;
	fnx = nx * factz;
	ny = *(unsigned char *)&cky[ips - 1] - 64;
	fny = -ny * factz;
	if (nx != -64) {
	    xp = xc + fnx * szbtx1_1.ct - fny * szbtx1_1.st;
	    yp = yc + fnx * szbtx1_1.st + fny * szbtx1_1.ct;
	    if (ip == 0) {
		szmvsv_(&xp, &yp);
	    } else if (ip == 1) {
		szplsv_(&xp, &yp);
	    }
	    ip = 1;
	} else {
	    ip = 0;
	}
	++ips;
	if (! (nx == -64 && ny == -64)) {
	    goto L10;
	}
	szclsv_();
L20:
	;
    }
    swocls_("SZTXZ", (ftnlen)5);
    return 0;
} /* sztxwv_ */
